@@ -64,6 +64,13 @@ XSD_DATA.update({
     '45': {
         'A19': 'A1945.xsd',
     },
+    '38': {
+        'A1': 'A138.xsd',
+        'A2': 'A238.xsd',
+        'A25': 'A2538.xsd',
+        'A3': 'A338.xsd',
+        'A4': 'A438.xsd',
+    }
 })
 
 MAIN_MESSAGE_XSD.update({
@@ -114,6 +121,12 @@ MAIN_MESSAGE_XSD.update({
     'A1226': 'a1226',
     # 45
     'A1945': 'a19',
+    # 38
+    'A138': 'a1',
+    'A238': 'a2',
+    'A2538': 'a25',
+    'A338': 'a3',
+    'A438': 'a4',
 })
 
 
